==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/connect/kotlin/inputs/InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.inputs

import com.pulumi.aws.connect.inputs.InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property encryptionType The type of encryption. Valid Values: `KMS`.
 * @property keyId The full ARN of the encryption key. Be sure to provide the full ARN of the encryption key, not just the ID.
 */
public data class InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs(
    public val encryptionType: Output<String>,
    public val keyId: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.connect.inputs.InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs> {
    override fun toJava():
        com.pulumi.aws.connect.inputs.InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs =
        com.pulumi.aws.connect.inputs.InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs.builder()
            .encryptionType(encryptionType.applyValue({ args0 -> args0 }))
            .keyId(keyId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs].
 */
@PulumiTagMarker
public class InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgsBuilder internal
constructor() {
    private var encryptionType: Output<String>? = null

    private var keyId: Output<String>? = null

    /**
     * @param value The type of encryption. Valid Values: `KMS`.
     */
    @JvmName("gqcsuekbwplljslu")
    public suspend fun encryptionType(`value`: Output<String>) {
        this.encryptionType = value
    }

    /**
     * @param value The full ARN of the encryption key. Be sure to provide the full ARN of the encryption key, not just the ID.
     */
    @JvmName("onabgkelueqqmjha")
    public suspend fun keyId(`value`: Output<String>) {
        this.keyId = value
    }

    /**
     * @param value The type of encryption. Valid Values: `KMS`.
     */
    @JvmName("tkqcuoldrnbqakej")
    public suspend fun encryptionType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.encryptionType = mapped
    }

    /**
     * @param value The full ARN of the encryption key. Be sure to provide the full ARN of the encryption key, not just the ID.
     */
    @JvmName("gaqxjajsfujstccr")
    public suspend fun keyId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyId = mapped
    }

    internal fun build(): InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs =
        InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs(
            encryptionType = encryptionType ?: throw PulumiNullFieldException("encryptionType"),
            keyId = keyId ?: throw PulumiNullFieldException("keyId"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/connect/kotlin/inputs/InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.inputs

import com.pulumi.aws.connect.inputs.InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property encryptionType The type of encryption. Valid Values: `KMS`.
 * @property keyId The full ARN of the encryption key. Be sure to provide the full ARN of the encryption key, not just the ID.
 */
public data class InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs(
    public val encryptionType: Output<String>,
    public val keyId: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.connect.inputs.InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs> {
    override fun toJava(): com.pulumi.aws.connect.inputs.InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs =
        com.pulumi.aws.connect.inputs.InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs.builder()
            .encryptionType(encryptionType.applyValue({ args0 -> args0 }))
            .keyId(keyId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs].
 */
@PulumiTagMarker
public class InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgsBuilder internal constructor() {
    private var encryptionType: Output<String>? = null

    private var keyId: Output<String>? = null

    /**
     * @param value The type of encryption. Valid Values: `KMS`.
     */
    @JvmName("kasfdkprgbwlyqsg")
    public suspend fun encryptionType(`value`: Output<String>) {
        this.encryptionType = value
    }

    /**
     * @param value The full ARN of the encryption key. Be sure to provide the full ARN of the encryption key, not just the ID.
     */
    @JvmName("hpltnxmiypfxlnsc")
    public suspend fun keyId(`value`: Output<String>) {
        this.keyId = value
    }

    /**
     * @param value The type of encryption. Valid Values: `KMS`.
     */
    @JvmName("yhqpitletevgwrtd")
    public suspend fun encryptionType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.encryptionType = mapped
    }

    /**
     * @param value The full ARN of the encryption key. Be sure to provide the full ARN of the encryption key, not just the ID.
     */
    @JvmName("odnsmxnxdciejlyx")
    public suspend fun keyId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyId = mapped
    }

    internal fun build(): InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs =
        InstanceStorageConfigStorageConfigS3ConfigEncryptionConfigArgs(
            encryptionType = encryptionType ?: throw PulumiNullFieldException("encryptionType"),
            keyId = keyId ?: throw PulumiNullFieldException("keyId"),
        )
}
